@@ -12,6 +12,7 @@ from uuid import uuid4
 def mkdir(folder):
     """Create a folder if it's not exists.
     """
+    folder = os.path.abspath(folder)
     if not os.path.exists(folder):
         os.makedirs(folder, exist_ok=True)
     return os.path.exists(folder) and os.path.isdir(folder)
@@ -116,12 +117,12 @@ def file_content_replace(filename, original, replacement, binary=False, encoding
             replace(filename, original, replacement, binary, encoding)
             file_replaced.append(filename)
         except Exception as error:
-            file_failed[path] = error
+            file_failed[filename] = error
             if not ignore_errors:
                 raise error
     else:
         folder = filename
-        for root, dirs, files in os.walk(folder):
+        for root, _, files in os.walk(folder):
             for filename in files:
                 path = os.path.abspath(os.path.join(root, filename))
                 try:
@@ -140,7 +141,7 @@ def touch(filename):
     if os.path.exists(filename):
         os.utime(filename, (time.time(), time.time()))
     else:
-        with open(filename, "wb") as fobj:
+        with open(filename, "wb") as _:
             pass
     return os.stat(filename)
 
@@ -268,10 +269,10 @@ def get_size_display(size_in_bytes):
 
 class TemporaryFile(object):
 
-    def __init__(self, content=None, encoding="utf-8", workspace=None, workspace_prefix="", touch_file=True):
-        self.workspace = workspace or get_temp_workspace(prefix=workspace_prefix)
+    def __init__(self, content=None, encoding="utf-8", workspace=None, filename_prefix="", filename_suffix="", touch_file=True):
+        self.workspace = workspace or tempfile.gettempdir()
         mkdir(self.workspace)
-        self.filename = str(uuid4())
+        self.filename = filename_prefix + str(uuid4()) + filename_suffix
         self.filepath = os.path.join(self.workspace, self.filename)
         if content:
             write(self.filepath, content, encoding)
@@ -282,8 +283,11 @@ class TemporaryFile(object):
         return self
     
     def __exit__(self, type, value, traceback):
-        if os.path.exists(self.filepath):
-            os.unlink(self.filepath)
-        if os.path.exists(self.workspace):
-            os.rmdir(self.workspace)
+        self.delete()
 
+    def __del__(self):
+        self.delete()
+
+    def delete(self):
+        if self.filepath and os.path.exists(self.filepath):
+            os.unlink(self.filepath)
